@@ -68,7 +68,7 @@ const MODULES_MAP: phf::Map<&str, &str> = phf::phf_map! {
 const JS_EXTENSIONS: &[&str] = &["js", "mjs", "jsx", "ts", "mts", "tsx", "svelte", "vue"];
 
 /// Returns a list of migrated plugins
-pub fn migrate(app_dir: &Path) -> Result<Vec<String>> {
+pub fn migrate(frontend_dir: &Path) -> Result<Vec<String>> {
   let mut new_npm_packages = Vec::new();
   let mut new_plugins = Vec::new();
   let mut npm_packages_to_remove = Vec::new();
@@ -84,14 +84,11 @@ pub fn migrate(app_dir: &Path) -> Result<Vec<String>> {
     )
   };
 
-  let pm = PackageManager::from_project(app_dir)
-    .into_iter()
-    .next()
-    .unwrap_or(PackageManager::Npm);
+  let pm = PackageManager::from_project(frontend_dir);
 
   for pkg in ["@tauri-apps/cli", "@tauri-apps/api"] {
     let version = pm
-      .current_package_version(pkg, app_dir)
+      .current_package_version(pkg, frontend_dir)
       .unwrap_or_default()
       .unwrap_or_default();
     if version.starts_with('1') {
@@ -99,7 +96,7 @@ pub fn migrate(app_dir: &Path) -> Result<Vec<String>> {
     }
   }
 
-  for entry in walk_builder(app_dir).build().flatten() {
+  for entry in walk_builder(frontend_dir).build().flatten() {
     if entry.file_type().map(|t| t.is_file()).unwrap_or_default() {
       let path = entry.path();
       let ext = path.extension().unwrap_or_default();
@@ -122,14 +119,14 @@ pub fn migrate(app_dir: &Path) -> Result<Vec<String>> {
   if !npm_packages_to_remove.is_empty() {
     npm_packages_to_remove.sort();
     npm_packages_to_remove.dedup();
-    pm.remove(&npm_packages_to_remove, app_dir)
+    pm.remove(&npm_packages_to_remove, frontend_dir)
       .context("Error removing npm packages")?;
   }
 
   if !new_npm_packages.is_empty() {
     new_npm_packages.sort();
     new_npm_packages.dedup();
-    pm.install(&new_npm_packages, app_dir)
+    pm.install(&new_npm_packages, frontend_dir)
       .context("Error installing new npm packages")?;
   }
 
