@@ -9,8 +9,10 @@ use tauri_runtime::{
   dpi::{PhysicalPosition, PhysicalSize, Position, Size},
   monitor::Monitor,
   webview::{DetachedWebview, PendingWebview},
-  window::{CursorIcon, DetachedWindow, PendingWindow, RawWindow, WindowEvent, WindowId},
-  window::{WindowBuilder, WindowBuilderBase},
+  window::{
+    CursorIcon, DetachedWindow, DetachedWindowWebview, PendingWindow, RawWindow, WindowBuilder,
+    WindowBuilderBase, WindowEvent, WindowId,
+  },
   DeviceEventFilter, Error, EventLoopProxy, ExitRequestedEventAction, Icon, ProgressBarState,
   Result, RunEvent, Runtime, RuntimeHandle, RuntimeInitArgs, UserAttentionType, UserEvent,
   WebviewDispatch, WindowDispatch, WindowEventId,
@@ -158,14 +160,17 @@ impl<T: UserEvent> RuntimeHandle<T> for MockRuntimeHandle {
       },
     );
 
-    let webview = webview_id.map(|id| DetachedWebview {
-      label: pending.label.clone(),
-      dispatcher: MockWebviewDispatcher {
-        id,
-        context: self.context.clone(),
-        url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
-        last_evaluated_script: Default::default(),
+    let webview = webview_id.map(|id| DetachedWindowWebview {
+      webview: DetachedWebview {
+        label: pending.label.clone(),
+        dispatcher: MockWebviewDispatcher {
+          id,
+          context: self.context.clone(),
+          url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
+          last_evaluated_script: Default::default(),
+        },
       },
+      use_https_scheme: false,
     });
 
     Ok(DetachedWindow {
@@ -416,6 +421,10 @@ impl WindowBuilder for MockWindowBuilder {
     self
   }
 
+  fn window_classname<S: Into<String>>(self, classname: S) -> Self {
+    self
+  }
+
   fn shadow(self, enable: bool) -> Self {
     self
   }
@@ -477,6 +486,10 @@ impl WindowBuilder for MockWindowBuilder {
   fn get_theme(&self) -> Option<Theme> {
     None
   }
+
+  fn background_color(self, _color: tauri_utils::config::Color) -> Self {
+    self
+  }
 }
 
 impl<T: UserEvent> WebviewDispatch<T> for MockWebviewDispatcher {
@@ -588,6 +601,10 @@ impl<T: UserEvent> WebviewDispatch<T> for MockWebviewDispatcher {
   fn show(&self) -> Result<()> {
     Ok(())
   }
+
+  fn set_background_color(&self, color: Option<tauri_utils::config::Color>) -> Result<()> {
+    Ok(())
+  }
 }
 
 impl<T: UserEvent> WindowDispatch<T> for MockWindowDispatcher {
@@ -773,14 +790,17 @@ impl<T: UserEvent> WindowDispatch<T> for MockWindowDispatcher {
       },
     );
 
-    let webview = webview_id.map(|id| DetachedWebview {
-      label: pending.label.clone(),
-      dispatcher: MockWebviewDispatcher {
-        id,
-        context: self.context.clone(),
-        url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
-        last_evaluated_script: Default::default(),
+    let webview = webview_id.map(|id| DetachedWindowWebview {
+      webview: DetachedWebview {
+        label: pending.label.clone(),
+        dispatcher: MockWebviewDispatcher {
+          id,
+          context: self.context.clone(),
+          url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
+          last_evaluated_script: Default::default(),
+        },
       },
+      use_https_scheme: false,
     });
 
     Ok(DetachedWindow {
@@ -979,6 +999,10 @@ impl<T: UserEvent> WindowDispatch<T> for MockWindowDispatcher {
   fn is_enabled(&self) -> Result<bool> {
     Ok(true)
   }
+
+  fn set_background_color(&self, color: Option<tauri_utils::config::Color>) -> Result<()> {
+    Ok(())
+  }
 }
 
 #[derive(Debug, Clone)]
@@ -1065,14 +1089,17 @@ impl<T: UserEvent> Runtime<T> for MockRuntime {
       },
     );
 
-    let webview = webview_id.map(|id| DetachedWebview {
-      label: pending.label.clone(),
-      dispatcher: MockWebviewDispatcher {
-        id,
-        context: self.context.clone(),
-        url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
-        last_evaluated_script: Default::default(),
+    let webview = webview_id.map(|id| DetachedWindowWebview {
+      webview: DetachedWebview {
+        label: pending.label.clone(),
+        dispatcher: MockWebviewDispatcher {
+          id,
+          context: self.context.clone(),
+          url: Arc::new(Mutex::new(pending.webview.unwrap().url)),
+          last_evaluated_script: Default::default(),
+        },
       },
+      use_https_scheme: false,
     });
 
     Ok(DetachedWindow {
